Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: recipes/skia_buildbot.py

Issue 777513002: Add fetch recipe for Skia's Buildbot repository. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipes/skia_buildbot.py
diff --git a/recipes/skia.py b/recipes/skia_buildbot.py
similarity index 72%
copy from recipes/skia.py
copy to recipes/skia_buildbot.py
index 171157c43ffaac2108a107db07e59981737d839e..42b6c8dad956c811ff87d5a7e7670223e70727d1 100644
--- a/recipes/skia.py
+++ b/recipes/skia_buildbot.py
@@ -9,14 +9,14 @@ import recipe_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Skia(recipe_util.Recipe):
- """Basic Recipe class for the Skia repository."""
+class SkiaBuildbot(recipe_util.Recipe):
+ """Basic Recipe class for the Skia Buildbot repository."""
@staticmethod
def fetch_spec(_props):
solution = {
- 'name' : 'skia',
- 'url' : 'https://skia.googlesource.com/skia.git',
+ 'name' : 'buildbot',
+ 'url' : 'https://skia.googlesource.com/buildbot.git',
'deps_file': 'DEPS',
'managed' : False,
}
@@ -30,11 +30,11 @@ class Skia(recipe_util.Recipe):
@staticmethod
def expected_root(_props):
- return 'skia'
+ return 'buildbot'
def main(argv=None):
- return Skia().handle_args(argv)
+ return SkiaBuildbot().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698